@@ -1,37 +1,24 @@
 /*
- * This file is part of the Polkit-qt project
- * Copyright (C) 2009 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
- * Copyright (C) 2009 Dario Freddi <drf@kde.org>
- * Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
- * Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB. If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the Polkit-qt project
+    SPDX-FileCopyrightText: 2009 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
+    SPDX-FileCopyrightText: 2009 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2009 Jaroslav Reznik <jreznik@redhat.com>
+    SPDX-FileCopyrightText: 2009 Radek Novacek <rnovacek@redhat.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef POLKITQT1_AUTHORITY_H
 #define POLKITQT1_AUTHORITY_H
 
-#include "polkitqt1-export.h"
+#include "polkitqt1-core-export.h"
 #include "polkitqt1-identity.h"
 #include "polkitqt1-subject.h"
 #include "polkitqt1-temporaryauthorization.h"
 #include "polkitqt1-actiondescription.h"
 
-#include <QtCore/QObject>
-#include <QtCore/QMetaType>
+#include <QObject>
+#include <QMetaType>
 
 typedef struct _PolkitAuthority PolkitAuthority;
 class QStringList;
@@ -65,12 +52,10 @@ typedef QMap<QString, QString> DetailsMap;
  * Call Authority::instance() to get an instance of the Authority object.
  * Do not delete Authority::instance(), cleanup will be done automatically.
  */
-class POLKITQT1_EXPORT Authority : public QObject
+class POLKITQT1_CORE_EXPORT Authority : public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY(Authority)
-    Q_ENUMS(Result)
-    Q_ENUMS(ErrorCode)
 public:
     enum Result {
         /** Result unknown */
@@ -82,6 +67,7 @@ public:
         /** The subject is authorized if more information is provided */
         Challenge = 0x03
     };
+    Q_ENUM(Result)
 
     enum AuthorizationFlag {
         /** No flags set **/
@@ -120,6 +106,7 @@ public:
         /** Revoke temporary authorizations failed **/
         E_RevokeFailed = 0x0A
     };
+    Q_ENUM(ErrorCode)
 
     /**
      * \brief Returns the instance of Authority
@@ -138,9 +125,9 @@ public:
      *
      * \return The current authority instance
      */
-    static Authority *instance(PolkitAuthority *authority = 0);
+    static Authority *instance(PolkitAuthority *authority = nullptr);
 
-    ~Authority();
+    ~Authority() override;
 
     /**
      * You should always call this method after every action. No action will be allowed
@@ -523,7 +510,7 @@ Q_SIGNALS:
     void authenticationAgentResponseFinished(bool);
 
     /**
-     * This signal is emmited when asynchronous method enumerateTemporaryAuthorizations finishes.
+     * This signal is emitted when asynchronous method enumerateTemporaryAuthorizations finishes.
      *
      * The argument is list of all temporary authorizations.
      *
@@ -532,7 +519,7 @@ Q_SIGNALS:
     void enumerateTemporaryAuthorizationsFinished(PolkitQt1::TemporaryAuthorization::List);
 
     /**
-     * This signal is emmited when asynchronous method revokeTemporaryAuthorizations finishes.
+     * This signal is emitted when asynchronous method revokeTemporaryAuthorizations finishes.
      *
      * The argument is \c true if all temporary authorizations were revoked
      *                 \c false if the revoking failed
@@ -540,14 +527,14 @@ Q_SIGNALS:
     void revokeTemporaryAuthorizationsFinished(bool);
 
     /**
-     * This signal is emmited when asynchronous method revokeTemporaryAuthorization finishes.
+     * This signal is emitted when asynchronous method revokeTemporaryAuthorization finishes.
      * \return \c true if the temporary authorization was revoked
      *         \c false if the revoking failed
      */
     void revokeTemporaryAuthorizationFinished(bool);
 
 private:
-    explicit Authority(PolkitAuthority *context, QObject *parent = 0);
+    explicit Authority(PolkitAuthority *context, QObject *parent = nullptr);
 
     class Private;
     friend class Private;
@@ -556,9 +543,8 @@ private:
     Q_PRIVATE_SLOT(d, void dbusFilter(const QDBusMessage &message))
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Authority::AuthorizationFlags)
+
 }
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(PolkitQt1::Authority::AuthorizationFlags)
-Q_DECLARE_METATYPE(PolkitQt1::Authority::Result)
-
 #endif
